==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_sharing/l10n/nb_NO.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Server til server-deling er ikke aktivert på denne serveren",
    "The mountpoint name contains invalid characters." : "Navnet på oppkoblingspunktet inneholder ugyldige tegn.",
    "Not allowed to create a federated share with the same user server" : "Ikke tillatt å opprette en Sammenknyttet sky-deling med den samme bruker-serveren",
    "Invalid or untrusted SSL certificate" : "Ugyldig eller ikke tiltrodd SSL-sertifikat",
    "Could not authenticate to remote share, password might be wrong" : "Klarte ikke å autentisere mot ekstern deling. Passordet kan være feil",
    "Storage not valid" : "Lagerplass ikke gyldig",
    "Couldn't add remote share" : "Klarte ikke å legge til ekstern deling",
    "Shared with you" : "Delt med deg",
    "Shared with others" : "Delt med andre",
    "Shared by link" : "Delt med lenke",
    "Federated sharing" : "Sammenknyttet deling",
    "Nothing shared with you yet" : "Ingenting er delt med deg ennå",
    "Files and folders others share with you will show up here" : "Filer og mapper som andre deler med deg vil bli vist her",
    "Nothing shared yet" : "Ingenting er delt ennå",
    "Files and folders you share will show up here" : "Filer og mapper som du deler vil bli vist her",
    "No shared links" : "Ingen delte lenker",
    "Files and folders you share by link will show up here" : "Filer og mapper som du deler med lenke vil bli vist her",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Ønsker du å legge til ekstern deling {name} fra {owner}@{remote}?",
    "Remote share" : "Ekstern deling",
    "Remote share password" : "Passord for ekstern deling",
    "Cancel" : "Avbryt",
    "Add remote share" : "Legg til ekstern deling",
    "You can upload into this folder" : "Du kan laste opp til denne mappen",
    "No ownCloud installation (7 or higher) found at {remote}" : "Ingen ownCloud-installasjon (7 eller høyere) funnet på {remote}",
    "Invalid ownCloud url" : "Ugyldig ownCloud-url",
    "Shared by" : "Delt av",
    "Sharing" : "Deling",
    "A file or folder has been <strong>shared</strong>" : "En fil eller mappe ble <strong>delt</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "En fil eller mappe ble delt fra <strong>en annen server</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "En offentlig delt fil eller mappe ble <strong>lastet ned</strong>",
    "You received a new remote share %2$s from %1$s" : "Du mottok en ny ekstern deling %2$s fra %1$s",
    "You received a new remote share from %s" : "Du mottok en ny ekstern deling fra %s",
    "%1$s accepted remote share %2$s" : "%1$s aksepterte ekstern deling %2$s",
    "%1$s declined remote share %2$s" : "%1$s avviste ekstern deling %2$s",
    "%1$s unshared %2$s from you" : "%1$s fjernet deling %2$s fra deg",
    "Public shared folder %1$s was downloaded" : "Offentlig delt mappe %1$s ble lastet ned",
    "Public shared file %1$s was downloaded" : "Offentlig delt fil %1$s ble lastet ned",
    "You shared %1$s with %2$s" : "Du delte %1$s med %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s delte %1$s med %3$s",
    "You removed the share of %2$s for %1$s" : "Du fjernet deling av %2$s for %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s fjernet deling av %3$s for %1$s",
    "You shared %1$s with group %2$s" : "Du delte %1$s med gruppe %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s delte %1$s med gruppe %3$s",
    "You removed the share of group %2$s for %1$s" : "Du fjernet deling av gruppe %2$s for %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s fjernet deling av gruppe %3$s for %1$s",
    "%2$s shared %1$s via link" : "%2$s delte %1$s via lenke",
    "You shared %1$s via link" : "Du delte %1$s via lenke",
    "You removed the public link for %1$s" : "Du fjernet den offentlige lenken for %1$s",
    "%2$s removed the public link for %1$s" : "%2$s fjernet den offentlige lenken for %1$s",
    "Your public link for %1$s expired" : "Din offentlige lenke for %1$s er utløpt",
    "The public link of %2$s for %1$s expired" : "Den offentlige lenken til %2$s for %1$s er utløpt",
    "%2$s shared %1$s with you" : "%2$s delte %1$s med deg",
    "%2$s removed the share for %1$s" : "%2$s fjernet delingen for %1$s",
    "Downloaded via public link" : "Nedlastet via offentlig lenke",
    "Shared with %2$s" : "Delt med %2$s",
    "Shared with %3$s by %2$s" : "Delt med %3$s av %2$s",
    "Removed share for %2$s" : "Fjernet deling for %2$s",
    "%2$s removed share for %3$s" : "%2$s fjernet deling for %3$s",
    "Shared with group %2$s" : "Delt med gruppe %2$s",
    "Shared with group %3$s by %2$s" : "Delt med gruppe %3$s av %2$s",
    "Removed share of group %2$s" : "Fjernet deling av gruppe %2$s",
    "%2$s removed share of group %3$s" : "%2$s fjernet deling av gruppe %3$s",
    "Shared via link by %2$s" : "Delt via lenke av %2$s",
    "Shared via public link" : "Delt via offentlig lenke",
    "Removed public link" : "Fjernet offentlig lenke",
    "%2$s removed public link" : "%2$s fjernet offentlig lenke",
    "Public link expired" : "Offentlig lenke er utløpt",
    "Public link of %2$s expired" : "Offentlig lenke til %2$s er utløpt",
    "Shared by %2$s" : "Delt av %2$s",
    "Shares" : "Delinger",
    "You received \"/%2$s\" as a remote share from %1$s" : "Du mottok \"/%2$s\" som en ekstern deling fra %1$s",
    "Accept" : "Aksepter",
    "Decline" : "Avslå",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Del med meg gjennom min #ownCloud ID for sammenknyttet sky, se %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Del med meg gjennom min #ownCloud ID for sammenknyttet sky",
    "This share is password-protected" : "Denne delingen er passordbeskyttet",
    "The password is wrong. Try again." : "Passordet er feil. Prøv på nytt.",
    "Password" : "Passord",
    "No entries found in this folder" : "Ingen oppføringer funnet i denne mappen",
    "Name" : "Navn",
    "Share time" : "Delingstidspunkt",
    "Sorry, this link doesn’t seem to work anymore." : "Beklager, denne lenken ser ikke ut til å virke lenger.",
    "Reasons might be:" : "Mulige årsaker:",
    "the item was removed" : "elementet er fjernet",
    "the link expired" : "lenken er utløpt",
    "sharing is disabled" : "deling er deaktivert",
    "For more info, please ask the person who sent this link." : "For mer informasjon, spør personen som sendte lenken.",
    "Add to your ownCloud" : "Legg til i din ownCloud",
    "Download" : "Last ned",
    "Download %s" : "Last ned %s",
    "Direct link" : "Direkte lenke",
    "Federated Cloud Sharing" : "Sammenknyttet sky-deling",
    "Open documentation" : "Åpne dokumentasjonen",
    "Allow users on this server to send shares to other servers" : "Tillat at brukere på denne serveren sender delinger til andre servere",
    "Allow users on this server to receive shares from other servers" : "Tillat at brukere på denne serveren mottar delinger fra andre servere",
    "Federated Cloud" : "Sammenknyttet sky",
    "Your Federated Cloud ID:" : "Din ID for sammenknyttet sky:",
    "Share it:" : "Del den:",
    "Add to your website" : "Legg på websiden din",
    "Share with me via ownCloud" : "Del med meg via ownCloud",
    "HTML Code:" : "HTML-kode:"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_sharing/l10n/nb_NO.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Server til server-deling er ikke aktivert på denne serveren",
    "The mountpoint name contains invalid characters." : "Navnet på oppkoblingspunktet inneholder ugyldige tegn.",
    "Not allowed to create a federated share with the same user server" : "Ikke tillatt å opprette en Sammenknyttet sky-deling med den samme bruker-serveren",
    "Invalid or untrusted SSL certificate" : "Ugyldig eller ikke tiltrodd SSL-sertifikat",
    "Could not authenticate to remote share, password might be wrong" : "Klarte ikke å autentisere mot ekstern deling. Passordet kan være feil",
    "Storage not valid" : "Lagerplass ikke gyldig",
    "Couldn't add remote share" : "Klarte ikke å legge til ekstern deling",
    "Shared with you" : "Delt med deg",
    "Shared with others" : "Delt med andre",
    "Shared by link" : "Delt med lenke",
    "Federated sharing" : "Sammenknyttet deling",
    "Nothing shared with you yet" : "Ingenting er delt med deg ennå",
    "Files and folders others share with you will show up here" : "Filer og mapper som andre deler med deg vil bli vist her",
    "Nothing shared yet" : "Ingenting er delt ennå",
    "Files and folders you share will show up here" : "Filer og mapper som du deler vil bli vist her",
    "No shared links" : "Ingen delte lenker",
    "Files and folders you share by link will show up here" : "Filer og mapper som du deler med lenke vil bli vist her",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Ønsker du å legge til ekstern deling {name} fra {owner}@{remote}?",
    "Remote share" : "Ekstern deling",
    "Remote share password" : "Passord for ekstern deling",
    "Cancel" : "Avbryt",
    "Add remote share" : "Legg til ekstern deling",
    "You can upload into this folder" : "Du kan laste opp til denne mappen",
    "No ownCloud installation (7 or higher) found at {remote}" : "Ingen ownCloud-installasjon (7 eller høyere) funnet på {remote}",
    "Invalid ownCloud url" : "Ugyldig ownCloud-url",
    "Shared by" : "Delt av",
    "Sharing" : "Deling",
    "A file or folder has been <strong>shared</strong>" : "En fil eller mappe ble <strong>delt</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "En fil eller mappe ble delt fra <strong>en annen server</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "En offentlig delt fil eller mappe ble <strong>lastet ned</strong>",
    "You received a new remote share %2$s from %1$s" : "Du mottok en ny ekstern deling %2$s fra %1$s",
    "You received a new remote share from %s" : "Du mottok en ny ekstern deling fra %s",
    "%1$s accepted remote share %2$s" : "%1$s aksepterte ekstern deling %2$s",
    "%1$s declined remote share %2$s" : "%1$s avviste ekstern deling %2$s",
    "%1$s unshared %2$s from you" : "%1$s fjernet deling %2$s fra deg",
    "Public shared folder %1$s was downloaded" : "Offentlig delt mappe %1$s ble lastet ned",
    "Public shared file %1$s was downloaded" : "Offentlig delt fil %1$s ble lastet ned",
    "You shared %1$s with %2$s" : "Du delte %1$s med %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s delte %1$s med %3$s",
    "You removed the share of %2$s for %1$s" : "Du fjernet deling av %2$s for %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s fjernet deling av %3$s for %1$s",
    "You shared %1$s with group %2$s" : "Du delte %1$s med gruppe %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s delte %1$s med gruppe %3$s",
    "You removed the share of group %2$s for %1$s" : "Du fjernet deling av gruppe %2$s for %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s fjernet deling av gruppe %3$s for %1$s",
    "%2$s shared %1$s via link" : "%2$s delte %1$s via lenke",
    "You shared %1$s via link" : "Du delte %1$s via lenke",
    "You removed the public link for %1$s" : "Du fjernet den offentlige lenken for %1$s",
    "%2$s removed the public link for %1$s" : "%2$s fjernet den offentlige lenken for %1$s",
    "Your public link for %1$s expired" : "Din offentlige lenke for %1$s er utløpt",
    "The public link of %2$s for %1$s expired" : "Den offentlige lenken til %2$s for %1$s er utløpt",
    "%2$s shared %1$s with you" : "%2$s delte %1$s med deg",
    "%2$s removed the share for %1$s" : "%2$s fjernet delingen for %1$s",
    "Downloaded via public link" : "Nedlastet via offentlig lenke",
    "Shared with %2$s" : "Delt med %2$s",
    "Shared with %3$s by %2$s" : "Delt med %3$s av %2$s",
    "Removed share for %2$s" : "Fjernet deling for %2$s",
    "%2$s removed share for %3$s" : "%2$s fjernet deling for %3$s",
    "Shared with group %2$s" : "Delt med gruppe %2$s",
    "Shared with group %3$s by %2$s" : "Delt med gruppe %3$s av %2$s",
    "Removed share of group %2$s" : "Fjernet deling av gruppe %2$s",
    "%2$s removed share of group %3$s" : "%2$s fjernet deling av gruppe %3$s",
    "Shared via link by %2$s" : "Delt via lenke av %2$s",
    "Shared via public link" : "Delt via offentlig lenke",
    "Removed public link" : "Fjernet offentlig lenke",
    "%2$s removed public link" : "%2$s fjernet offentlig lenke",
    "Public link expired" : "Offentlig lenke er utløpt",
    "Public link of %2$s expired" : "Offentlig lenke til %2$s er utløpt",
    "Shared by %2$s" : "Delt av %2$s",
    "Shares" : "Delinger",
    "You received \"/%2$s\" as a remote share from %1$s" : "Du mottok \"/%2$s\" som en ekstern deling fra %1$s",
    "Accept" : "Aksepter",
    "Decline" : "Avslå",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Del med meg gjennom min #ownCloud ID for sammenknyttet sky, se %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Del med meg gjennom min #ownCloud ID for sammenknyttet sky",
    "This share is password-protected" : "Denne delingen er passordbeskyttet",
    "The password is wrong. Try again." : "Passordet er feil. Prøv på nytt.",
    "Password" : "Passord",
    "No entries found in this folder" : "Ingen oppføringer funnet i denne mappen",
    "Name" : "Navn",
    "Share time" : "Delingstidspunkt",
    "Sorry, this link doesn’t seem to work anymore." : "Beklager, denne lenken ser ikke ut til å virke lenger.",
    "Reasons might be:" : "Mulige årsaker:",
    "the item was removed" : "elementet er fjernet",
    "the link expired" : "lenken er utløpt",
    "sharing is disabled" : "deling er deaktivert",
    "For more info, please ask the person who sent this link." : "For mer informasjon, spør personen som sendte lenken.",
    "Add to your ownCloud" : "Legg til i din ownCloud",
    "Download" : "Last ned",
    "Download %s" : "Last ned %s",
    "Direct link" : "Direkte lenke",
    "Federated Cloud Sharing" : "Sammenknyttet sky-deling",
    "Open documentation" : "Åpne dokumentasjonen",
    "Allow users on this server to send shares to other servers" : "Tillat at brukere på denne serveren sender delinger til andre servere",
    "Allow users on this server to receive shares from other servers" : "Tillat at brukere på denne serveren mottar delinger fra andre servere",
    "Federated Cloud" : "Sammenknyttet sky",
    "Your Federated Cloud ID:" : "Din ID for sammenknyttet sky:",
    "Share it:" : "Del den:",
    "Add to your website" : "Legg på websiden din",
    "Share with me via ownCloud" : "Del med meg via ownCloud",
    "HTML Code:" : "HTML-kode:",
    "Public link of %2$s expired" : "Offentlig lenke til %2$s er utløpt",
    "Public shared file %1$s was downloaded" : "Offentlig delt fil %1$s ble lastet ned",
    "Public shared folder %1$s was downloaded" : "Offentlig delt mappe %1$s ble lastet ned",
    "Removed share for %2$s" : "Fjernet deling for %2$s",
    "Removed share of group %2$s" : "Fjernet deling av gruppe %2$s",
    "Shared by %2$s" : "Delt av %2$s",
    "Shared via link by %2$s" : "Delt via lenke av %2$s",
    "Shared with group %3$s by %2$s" : "Delt med gruppe %3$s av %2$s",
    "The public link of %2$s for %1$s expired" : "Den offentlige lenken til %2$s for %1$s er utløpt",
    "You removed the public link for %1$s" : "Du fjernet den offentlige lenken for %1$s",
    "You removed the share of %2$s for %1$s" : "Du fjernet deling av %2$s for %1$s",
    "You removed the share of group %2$s for %1$s" : "Du fjernet deling av gruppe %2$s for %1$s",
    "Your public link for %1$s expired" : "Din offentlige lenke for %1$s er utløpt"
},
"nplurals=2; plural=(n != 1);");
